; Instrument-specific parameters for MIKE (either CCD)
;
; Bias and read noise parameters below are for the red CCD.  The correct
; values for both the blue and red CCDs are set in mike_reduce.pro.
;
; The 'prescan' region is actually the overscan region that extends in
; the y-direction.
;
; 'traceobj' should be set to 0.  User can specify which orders to reduce
; in MIKE_REDUCE.
;
; Assumes 2x2 binning.

nchip         = 1        ; Number of CCDs included in each array
chip_xmin     = [0]      ; Min x for each chip (not including overscan)
chip_xmax     = [1023]   ; Max x for each chip (not including overscan)
chip_ymin     = [0]      ; Min y for each chip (not including overscan)
chip_ymax     = [2047]   ; Max y for each chip (not including overscan)
namp          = 1        ; Number of amplifiers
gain          = [1.00]   ; Gain for each amplifier (e-/ADU)
amp_xmin      = [0]      ; Min x for each amplifier (not including overscan)
amp_xmax      = [1023]   ; Max x for each amplifier (not including overscan)
amp_ymin      = [0]      ; Min y for each amplifier (not including overscan)
amp_ymax      = [2047]   ; Max y for each amplifier (not including overscan)
erdnoise      = 3.50     ; Read noise (e-)
satlevel      = 60000.   ; Saturation level (ADU) 
dispdir       = 'y'      ; Dispersion direction, 'x' or 'y'
prescan_x     = [0,1023]    ; [x_min,x_max] of prescan region (-1 = none)
prescan_y     = [2048,2175] ; [y_min,y_max] of prescan region (-1 = none)
oscan_x       = [1024,1151] ; [x_min,x_max] of overscan region (-1 = none)
oscan_y       = [0,2175]    ; [y_min,y_max] of overscan region (-1 = none)
trim          = 0     ; Trim pre/overscan regions before processing?
rotate        = 0     ; Rotate frame (90 deg clockwise) before processing?
darkcurrent   = 0.0   ; Dark current (e-/sec/pixel)
badpixelfile  = -1    ; Filename of bad pixel map (-1 = none)
bk_space      = 0.3  ;0.3   ; Initial spacing of b-spline break points, in input wave units
min_bk_space  = 0.1  ;0.1   ; Minimum spacing of b-spline break points, in input wave units
slitedge1     = -9000   ; First edge of slit, in slit position coords
slitedge2     = 9000  ; Second edge of slit, in slit position coords
wavemin       = -1e6  ; Min input wavelength over which to locate object
wavemax       = 1e6  ; Max input wavelength over which to locate object
slitmin       = -9000   ; Min input slit position over which to locate object
slitmax       = 9000  ; Max input slit position over which to locate object
sub_width     = 1000.  ; Range in slit position over which to perform sky subtraction
dispersion    = 0.1   ; Approximate dispersion, in ang/input wave unit (pixel)
wavebin       = 5.    ; Binning for extracted spectrum (km/s if /loglin set)
illum_poly    = 1.    ; 1 + polynomial order for slit illumination fn (2 = linear)
x_display     = [0,1023] ; [xmin,xmax] for display of subtracted array
y_display     = [600,1400] ; [ymin,ymax] for display of subtracted array
traceobj      = 0          ; Trace object with respect to slit position? (1 = yes)
bestprofile   = 1          ; Estimate object profile using entire spectrum? (1 = yes)
line_file     = '~gdb/calib/hires/linelists/uves_sky_atlas/uves_sky_formatted_strong_red.dat' ; Default sky line list
wave_model    = -1        ; Default tabulated sky model
getsubarray   = 0         ; Extract sub-arrays for output files? (1 = yes)
subarray_x    = [0,1151]  ; [xmin,xmax] of extracted subarray
subarray_y    = [0,2175]  ; [ymin,ymax] of extracted subarray
latitude      = -29.0033  ; Observatory latitude (degrees; Keck = 19.8283)
longitude     = 70.7017   ; Observatory longitude (degrees; Keck = 155.478)
altitude      = 2282.     ; Observatory altitude (meters; Keck = 4160.)
